<?php 
$DatabaseType = 'mysqli'; 
$DatabaseServer = '[[softdbhost]]'; 
$DatabaseUsername = '[[softdbuser]]'; 
$DatabasePassword = '[[softdbpass]]'; 
$DatabaseName = '[[softdb]]'; 
$DatabasePort = '3306'; 
?>